@@ -13,10 +13,14 @@ CircuitPython scatter graph
 
 
 """
+try:
+    from circuitpython_uplot.uplot import Uplot
+except ImportError:
+    pass
 from bitmaptools import draw_line
 from vectorio import Rectangle
 
-__version__ = "0.6.0"
+__version__ = "0.7.0"
 __repo__ = "https://github.com/adafruit/CircuitPython_uplot.git"
 
 # pylint: disable=too-many-arguments, invalid-name, protected-access
@@ -26,12 +30,22 @@ class ubar:
     Main class to display different graphics
     """
 
-    def __init__(self, plot, x: any, y: any, color=0xFFFFFF, fill=False) -> None:
+    def __init__(
+        self, plot: Uplot, x: list, y: list, color: int = 0xFFFFFF, fill: bool = False
+    ) -> None:
+        """
+        :param Uplot plot: Plot object for the scatter to be drawn
+        :param list x: x data
+        :param list y: y data
+        :param int color: boxes color. Defaults to const:``0xFFFFFF``
+        :param bool fill: boxes fill attrribute. Defaults to `False`
+
+        """
 
         self._graphx = abs(plot._newxmax - plot._newxmin) // (len(x) + 2)
         self._graphy = abs(plot._newymax - plot._newymin) // (max(y) + 2)
-        self._new_min = int(plot.normalize(0, max(y), max(y), 0, 0))
-        self._new_max = int(plot.normalize(0, max(y), max(y), 0, max(y)))
+        self._new_min = int(plot.transform(0, max(y), max(y), 0, 0))
+        self._new_max = int(plot.transform(0, max(y), max(y), 0, max(y)))
 
         bar_space = max(2, plot._width // 30)
         xstart = self._graphx + bar_space
@@ -50,6 +64,11 @@ class ubar:
                         color_index=plot._index_colorused,
                     )
                 )
+                plot.show_text(
+                    str(y[i]),
+                    xstart + (i * self._graphx) + self._graphx // 2,
+                    plot._newymin,
+                )
                 xstart = xstart + bar_space
                 plot._index_colorused = plot._index_colorused + 1
         else:
@@ -65,8 +84,15 @@ class ubar:
                 )
                 xstart = xstart + bar_space
                 plot._index_colorused = plot._index_colorused + 1
+                plot.show_text(
+                    str(y[i]),
+                    xstart + (i * self._graphx) - bar_space + self._graphx // 2,
+                    plot._newymin,
+                )
 
-    def _draw_rectangle(self, plot, x, y, width, height, color):
+    def _draw_rectangle(
+        self, plot: Uplot, x: int, y: int, width: int, height: int, color: int
+    ) -> None:
         """
         Helper function to draw bins rectangles
         """
