@@ -13,17 +13,22 @@ CircuitPython cartesian graph
 
 
 """
+try:
+    from typing import Optional, Union
+    from circuitpython_uplot.uplot import Uplot
+except ImportError:
+    pass
 
 from bitmaptools import draw_line
 from ulab import numpy as np
 from vectorio import Polygon
 
-
-__version__ = "0.6.0"
+__version__ = "0.7.0"
 __repo__ = "https://github.com/adafruit/CircuitPython_uplot.git"
 
+
 # pylint: disable=too-many-arguments, invalid-name, no-self-use, too-few-public-methods
-# pylint: disable=too-many-locals
+# pylint: disable=too-many-locals, too-many-branches
 class ucartesian:
     """
     Class to draw cartesian plane
@@ -31,34 +36,46 @@ class ucartesian:
 
     def __init__(
         self,
-        plot,
-        x: any,
-        y: any,
-        rangex: any = None,
-        rangey: any = None,
-        line_color: int = 0xFFFFFF,
+        plot: Uplot,
+        x: Union[list, np.linspace, np.ndarray],
+        y: Union[list, np.linspace, np.ndarray],
+        rangex: Optional[Union[list, None]] = None,
+        rangey: Optional[Union[list, None]] = None,
+        line_color: Optional[Union[int, None]] = None,
         fill: bool = False,
+        nudge: bool = True,
     ) -> None:
         """
 
-        :param plot: Plot object for the scatter to be drawn
-        :param x: x points coordinates
-        :param y: y points coordinates
+        :param Uplot plot: Plot object for the scatter to be drawn
+        :param list|ulab.numpy.linspace|ulab.numpy.ndarray x: x points coordinates
+        :param list|ulab.numpy.linspace|ulab.numpy.ndarray y: y points coordinates
+        :param list|None rangex: x range limits. Defaults to None
+        :param list|None rangey: y range limits. Defaults to None
+        :param int|None line_color: line color. Defaults to None
+        :param bool fill: Show the filling. Defaults to `False`
+        :param bool nudge: moves the graph a little for better displaying. Defaults to `True`
 
         """
         points = []
-        plot._plot_palette[plot._index_colorused] = line_color
+        if line_color is not None:
+            plot._plot_palette[plot._index_colorused] = line_color
+
+        if nudge:
+            nudge_factor = 1
+        else:
+            nudge_factor = 0
 
         if rangex is None:
-            xmin = np.min(x)
-            xmax = np.max(x)
+            xmin = np.min(x) - nudge_factor * (abs(np.max(x) - np.min(x)) / 10)
+            xmax = np.max(x) + nudge_factor * (abs(np.max(x) - np.min(x)) / 10)
         else:
             xmin = min(rangex)
             xmax = max(rangex)
 
         if rangey is None:
-            ymin = np.min(y)
-            ymax = np.max(y)
+            ymin = np.min(y) - nudge_factor * (abs(np.max(y) - np.min(y)) / 10)
+            ymax = np.max(y) + nudge_factor * (abs(np.max(y) - np.min(y)) / 10)
         else:
             ymin = min(rangey)
             ymax = max(rangey)
@@ -67,12 +84,12 @@ class ucartesian:
         y = np.array(y)
 
         xnorm = np.array(
-            plot.normalize(xmin, xmax, plot._newxmin, plot._newxmax, x),
-            dtype=np.uint16,
+            plot.transform(xmin, xmax, plot._newxmin, plot._newxmax, x),
+            dtype=np.int16,
         )
         ynorm = np.array(
-            plot.normalize(ymin, ymax, plot._newymin, plot._newymax, y),
-            dtype=np.uint16,
+            plot.transform(ymin, ymax, plot._newymin, plot._newymax, y),
+            dtype=np.int16,
         )
 
         if fill:
@@ -103,6 +120,9 @@ class ucartesian:
                     plot._index_colorused,
                 )
         if plot._showticks:
-            plot._draw_ticks(x, y)
+            if plot._cartesianfirst:
+                plot._draw_ticks(x, y)
+                plot._cartesianfirst = False
+                plot._showticks = False
 
         plot._index_colorused = plot._index_colorused + 1
