@@ -13,11 +13,16 @@ CircuitPython pie graph
 
 
 """
+try:
+    from circuitpython_uplot.uplot import Uplot
+except ImportError:
+    pass
+
 
 import math
 from vectorio import Polygon
 
-__version__ = "0.6.0"
+__version__ = "0.7.0"
 __repo__ = "https://github.com/adafruit/CircuitPython_uplot.git"
 
 # pylint: disable=too-many-arguments, invalid-name, no-self-use
@@ -26,10 +31,12 @@ class upie:
     Class to draw pie
     """
 
-    def __init__(self, plot, data: list, x: int = 0, y: int = 0, radius: int = 50):
+    def __init__(
+        self, plot: Uplot, data: list, x: int = 0, y: int = 0, radius: int = 50
+    ) -> None:
         """
 
-        :param plot: Plot object for the upie to be drawn
+        :param Uplot plot: Plot object for the upie to be drawn
         :param list data: data to make the pie
         :param x: pie center x coordinate
         :param y: pie center y coordinate
@@ -63,7 +70,7 @@ class upie:
             index_color = index_color + 1
             self.pointlist = [(x, y)]
 
-    def get_points(self, x, y, radius, angle):
+    def get_points(self, x: int, y: int, radius: int, angle: float) -> None:
         """
 
         :param bitmap: bitmap to be drawn in
