@@ -22,23 +22,27 @@ Implementation Notes
 """
 
 try:
-    from typing import Union
+    from typing import Union, Tuple
     from typing_extensions import Literal
 except ImportError:
     pass
 
 import displayio
+import terminalio
 from bitmaptools import draw_line
 from vectorio import Circle
 from ulab import numpy as np
 
 
-__version__ = "0.6.0"
+__version__ = "0.7.0"
 __repo__ = "https://github.com/adafruit/CircuitPython_uplot.git"
 
 
 # pylint: disable=too-many-arguments, too-many-instance-attributes, too-many-locals
 # pylint: disable=too-many-statements
+# pylint: disable=unused-import, import-outside-toplevel, undefined-variable
+
+
 class Uplot(displayio.Group):
     """
     Canvas Class to add different elements to the screen.
@@ -50,6 +54,7 @@ class Uplot(displayio.Group):
     :param int height: plot box height in pixels
     :param int padding: padding for the plot box in all directions
     :param bool show_box: select if the plot box is displayed
+    :param int background_color: background color in HEX. Defaults to black ``0x000000``
 
     """
 
@@ -59,8 +64,9 @@ class Uplot(displayio.Group):
         y: int = 0,
         width: int = 100,
         height: int = 100,
-        padding: int = 15,
+        padding: int = 25,
         show_box: bool = True,
+        background_color: int = 0x000000,
     ) -> None:
         if width not in range(50, 481):
             print("Be sure to verify your values. Defaulting to width=100")
@@ -95,13 +101,17 @@ class Uplot(displayio.Group):
         self._newymin = height - padding
         self._newymax = padding
 
+        self._cartesianfirst = True
+
+        self._showtext = False
+
         self._tickheight = 8
         self._tickcolor = 0xFFFFFF
         self._showticks = False
         self._tickgrid = False
 
-        self._grid_espace = self._width // 40
-        self._grid_lenght = self._width // 20
+        self._grid_espace = 2
+        self._grid_lenght = 2
 
         self._barcolor = 0x69FF8F
 
@@ -115,7 +125,7 @@ class Uplot(displayio.Group):
             self._drawbox()
 
         self._plot_palette = displayio.Palette(14)
-        self._plot_palette[0] = 0x000000
+        self._plot_palette[0] = background_color
         self._plot_palette[1] = 0xFFFFFF
         self._plot_palette[2] = self._tickcolor
         self._plot_palette[3] = self._barcolor
@@ -140,12 +150,13 @@ class Uplot(displayio.Group):
         Setting up axs visibility
 
         :param axstype: argument with the kind of axs you selected
+
         :return: None
 
         """
         self._axesparams = axstype
 
-    def _drawbox(self):
+    def _drawbox(self) -> None:
         """
         Draw the plot box
 
@@ -214,7 +225,7 @@ class Uplot(displayio.Group):
         self.append(Circle(pixel_shader=palette, radius=radius, x=x, y=y))
 
     @staticmethod
-    def normalize(
+    def transform(
         oldrangemin: Union[float, int],
         oldrangemax: Union[float, int],
         newrangemin: Union[float, int],
@@ -229,6 +240,7 @@ class Uplot(displayio.Group):
         :param int|float newrangemin: minimum of the new range
         :param int|float newrangemax: maximum of the new range
         :param int|float value: value to be converted
+
         :return int|float: converted value
 
         """
@@ -244,44 +256,44 @@ class Uplot(displayio.Group):
 
         :param int x: x coord
         :param int y: y coord
+
         :return:None
 
         """
 
         ticks = np.array([10, 30, 50, 70, 90])
         subticks = np.array([20, 40, 60, 80])
-        ticksxnorm = np.array(self.normalize(0, 100, np.min(x), np.max(x), ticks))
-        ticksynorm = np.array(self.normalize(0, 100, np.min(y), np.max(y), ticks))
+        ticksxnorm = np.array(self.transform(0, 100, np.min(x), np.max(x), ticks))
+        ticksynorm = np.array(self.transform(0, 100, np.min(y), np.max(y), ticks))
 
-        subticksxnorm = np.array(self.normalize(0, 100, np.min(x), np.max(x), subticks))
-        subticksynorm = np.array(self.normalize(0, 100, np.min(y), np.max(y), subticks))
+        subticksxnorm = np.array(self.transform(0, 100, np.min(x), np.max(x), subticks))
+        subticksynorm = np.array(self.transform(0, 100, np.min(y), np.max(y), subticks))
 
         ticksxrenorm = np.array(
-            self.normalize(
+            self.transform(
                 np.min(x), np.max(x), self._newxmin, self._newxmax, ticksxnorm
             ),
-            dtype=np.uint16,
+            dtype=np.int16,
         )
         ticksyrenorm = np.array(
-            self.normalize(
+            self.transform(
                 np.min(y), np.max(y), self._newymin, self._newymax, ticksynorm
             ),
-            dtype=np.uint16,
+            dtype=np.int16,
         )
         subticksxrenorm = np.array(
-            self.normalize(
+            self.transform(
                 np.min(x), np.max(x), self._newxmin, self._newxmax, subticksxnorm
             ),
-            dtype=np.uint16,
+            dtype=np.int16,
         )
         subticksyrenorm = np.array(
-            self.normalize(
+            self.transform(
                 np.min(y), np.max(y), self._newymin, self._newymax, subticksynorm
             ),
-            dtype=np.uint16,
+            dtype=np.int16,
         )
-
-        for tick in ticksxrenorm:
+        for i, tick in enumerate(ticksxrenorm):
             draw_line(
                 self._plotbitmap,
                 tick,
@@ -290,7 +302,11 @@ class Uplot(displayio.Group):
                 self._newymin - self._tickheight,
                 2,
             )
-        for tick in ticksyrenorm:
+            if self._showtext:
+                self.show_text(
+                    "{:.2f}".format(ticksxnorm[i]), tick, self._newymin, (0.5, 0.0)
+                )
+        for i, tick in enumerate(ticksyrenorm):
             draw_line(
                 self._plotbitmap,
                 self._newxmin,
@@ -299,6 +315,10 @@ class Uplot(displayio.Group):
                 tick,
                 2,
             )
+            if self._showtext:
+                self.show_text(
+                    "{:.2f}".format(ticksynorm[i]), self._newxmin, tick, (1.0, 0.5)
+                )
         for tick in subticksxrenorm:
             draw_line(
                 self._plotbitmap,
@@ -323,7 +343,11 @@ class Uplot(displayio.Group):
             self._draw_gridy(ticksyrenorm)
 
     def tick_params(
-        self, tickheight: int = 8, tickcolor: int = 0xFFFFFF, tickgrid: bool = False
+        self,
+        tickheight: int = 8,
+        tickcolor: int = 0xFFFFFF,
+        tickgrid: bool = False,
+        showtext: bool = False,
     ) -> None:
         """
         Function to set ticks parameters
@@ -331,6 +355,7 @@ class Uplot(displayio.Group):
         :param int tickheight: tick height in pixels
         :param int tickcolor: tick color in hex
         :param bool tickgrid: defines if the grid is to be shown
+
         :return: None
 
         """
@@ -339,17 +364,22 @@ class Uplot(displayio.Group):
         self._tickheight = tickheight
         self._plot_palette[2] = tickcolor
         self._tickgrid = tickgrid
+        self._showtext = showtext
+        if self._showtext:
+            from adafruit_display_text import bitmap_label
 
     def _draw_gridx(self, ticks_data: list[int]) -> None:
         """
         Draws the plot grid
+
         :param list[int] ticks_data: ticks data information
+
         :return: None
 
         """
         for tick in ticks_data:
             start = self._newymin
-            while start - self._grid_lenght >= self._newymax:
+            while start - self._grid_lenght - self._grid_espace >= self._newymax:
                 draw_line(
                     self._plotbitmap,
                     tick,
@@ -363,13 +393,15 @@ class Uplot(displayio.Group):
     def _draw_gridy(self, ticks_data: list[int]) -> None:
         """
         Draws plot grid in the y axs
+
         :param list[int] ticks_data: ticks data information
+
         :return: None
 
         """
         for tick in ticks_data:
             start = self._newxmin
-            while start <= self._newxmax:
+            while start + self._grid_lenght <= self._newxmax:
                 draw_line(
                     self._plotbitmap,
                     start,
@@ -389,3 +421,21 @@ class Uplot(displayio.Group):
         """
 
         self._drawbox()
+
+    def show_text(
+        self, text: str, x: int, y: int, anchorpoint: Tuple = (0.5, 0.0)
+    ) -> None:
+        """
+
+        Show desired text in the scree
+        :param str text: text to be displayed
+        :param int x: x coordinate
+        :param int y: y coordinate
+        :param Tuple anchorpoint: Display_text anchor point. Defaults to (0.5, 0.0)
+        :return: None
+        """
+        if self._showtext:
+            text_toplot = bitmap_label.Label(terminalio.FONT, text=text, x=x, y=y)
+            text_toplot.anchor_point = anchorpoint
+            text_toplot.anchored_position = (x, y)
+            self.append(text_toplot)
